@@ -1,5 +1,5 @@
 /*
-   Copyright (C) 2012-2019 Montel Laurent <montel@kde.org>
+   Copyright (C) 2012-2020 Laurent Montel <montel@kde.org>
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public
@@ -46,7 +46,7 @@ bool AbstractAddressBook::selectAddressBook()
         QPointer<Akonadi::CollectionDialog> dlg = new Akonadi::CollectionDialog(mAbstractDisplayInfo ? mAbstractDisplayInfo->parentWidget() : nullptr);
         dlg->setMimeTypeFilter(mimeTypes);
         dlg->setAccessRightsFilter(Akonadi::Collection::CanCreateItem);
-        dlg->setWindowTitle(i18n("Select Address Book"));
+        dlg->setWindowTitle(i18nc("@title:window", "Select Address Book"));
         dlg->setDescription(i18n("Select the address book the new contact shall be saved in:"));
 
         if (dlg->exec() == QDialog::Accepted && dlg) {
